@@ -20,19 +20,13 @@
 # limitations under the License.
 
 from __future__ import print_function
-from opsramp.base import ApiWrapper
+from opsramp.api import ORapi
 
 
-class Roles(ApiWrapper):
+class Roles(ORapi):
     def __init__(self, parent):
         super(Roles, self).__init__(parent.api, 'roles')
 
-    def search(self, pattern=''):
-        suffix = 'search'
-        if pattern:
-            suffix += '?' + pattern
-        return self.api.get(suffix)
-
     def create(self, definition):
         return self.api.post('', json=definition)
 
@@ -43,11 +37,12 @@ class Roles(ApiWrapper):
         return self.api.delete('%s' % uuid)
 
 
-class PermissionSets(ApiWrapper):
+class PermissionSets(ORapi):
     def __init__(self, parent):
         super(PermissionSets, self).__init__(parent.api, 'permissionSets')
 
     def search(self, pattern=''):
-        if pattern:
-            pattern = '?' + pattern
-        return self.api.get(pattern)
+        return super(PermissionSets, self).search(
+            pattern=pattern,
+            suffix=''
+        )
