@@ -21,7 +21,7 @@
 # limitations under the License.
 
 set -eux -o pipefail
-flake8 --ignore=none --exclude=.git,__pycache__,.tox,.eggs,*.egg,venv,venv2,venv3
+flake8
 coverage run --include='opsramp/*' -m pytest -vvv
 coverage report
 coverage html
